@@ -13,11 +13,9 @@
 # statistics
 #
 # --PARAMETERS--
-#   g         : a network object
-#   model     : a model for 'g', as returned by <ergm_model>
-#   proposal: an proposal object, as returned by <proposal>
-#   eta0      : the vector of initial eta coefficients
-#   control: a list of control parameters for the MCMC algorithm;
+#   s         : ergm state object
+#   theta0    : the vector of initial theta coefficients
+#   control   : a list of control parameters for the MCMC algorithm;
 #               recognized components include:
 #                     'maxedges'     'samplesize'     'gain'
 #                     'stats'        'phase1'         'nsub'
@@ -49,8 +47,9 @@ ergm.phase12 <- function(s, theta0,
             s,
             # Phase12 settings
             as.double(deInf(theta0)),
-            as.integer(control$MCMC.samplesize), as.integer(control$MCMC.burnin), as.integer(control$MCMC.interval),
-            as.double(control$gain), as.integer(control$phase1), as.integer(control$nsub),
+            as.integer(control$MCMC.burnin), as.integer(control$MCMC.interval),
+            as.double(control$SA.initial_gain), as.integer(control$SA.phase1_n), as.integer(control$SA.nsubphases),
+            as.integer(control$SA.min_iterations), as.integer(control$SA.max_iterations),
             as.integer(deInf(NVL(control$MCMC.maxedges,Inf),"maxint")),
             as.integer(verbose),
             PACKAGE="ergm")
@@ -59,22 +58,16 @@ ergm.phase12 <- function(s, theta0,
             s,
             # Phase12 settings
             as.double(deInf(theta0)),
-            as.integer(control$MCMC.samplesize), as.integer(control$MCMC.burnin), as.integer(control$MCMC.interval),
-            as.double(control$gain), as.integer(control$phase1), as.integer(control$nsub),
+            as.integer(control$MCMC.burnin), as.integer(control$MCMC.interval),
+            as.double(control$SA.initial_gain), as.integer(control$SA.phase1_n), as.integer(control$SA.nsubphases),
+            as.integer(control$SA.min_iterations), as.integer(control$SA.max_iterations),
             as.integer(deInf(NVL(control$MCMC.maxedges,Inf),"maxint")),
             as.integer(verbose),
             PACKAGE="ergm")
 
-  statsmatrix <- matrix(z$s, nrow=control$MCMC.samplesize,
-                        ncol=nparam(s,canonical=TRUE),
-                        byrow = TRUE)
+  if(z$status) return(z) # If there is an error.
+
   theta <- z$theta
   names(theta) <- names(theta0)
-
-  z$state <- update(z$state)
-  newnetwork<-as.network(z$state)
-  
-  colnames(statsmatrix) <- param_names(s,canonical=TRUE)
-  list(statsmatrix=statsmatrix, newnetwork=newnetwork, target.stats=as.ergm_model(s)$target.stats, nw.stats=as.ergm_model(s)$nw.stats,
-       theta=theta, state=z$state)
+  list(status = z$status, theta=theta, state=update(z$state))
 }
