@@ -235,23 +235,6 @@ single.impute.dyads <- function(nw, constraints=NULL, constraints.obs=NULL, min_
   nw
 }
 
-# executes expression, returns the result in a list with any warnings and errors
-.catchToList <- function(expr) {
-  val <- NULL
-  myWarnings <- NULL
-  wHandler <- function(w) {
-    myWarnings <<- c(myWarnings, w$message)
-    invokeRestart("muffleWarning")
-  }
-  myError <- NULL
-  eHandler <- function(e) {
-    myError <<- e$message
-    NULL
-  }
-  val <- tryCatch(withCallingHandlers(expr, warning = wHandler), error = eHandler)
-  list(value = val, warnings = myWarnings, error=myError)
-} 
-
 ## A is a matrix. V is a column vector that may contain Infs
 ## computes A %*% V, counting 0*Inf as 0
 .multiply.with.inf <- function(A,V) {
@@ -281,134 +264,3 @@ trim_env_const_formula <- function(x, keep=NULL){
 
   if(needs_env) x else trim_env(x, keep)
 }
-
-#' Test if the object is a matrix that is symmetric and positive definite.
-#' @param x the object to be tested.
-#' @param tol the tolerance for the reciprocal condition number.
-#' @noRd
-is.SPD <- function(x, tol = .Machine$double.eps){
-  is.matrix(x) &&
-    nrow(x) == ncol(x) &&
-    all(x == t(x)) &&
-    rcond(x) >= tol &&
-    all(eigen(x, symmetric=TRUE, only.values=TRUE)$values > 0)
-}
-
-# ssolve() and sginv() (for *s*caled) are thin wrappers around
-# base::solve() and MASS::ginv() that first scale the matrix's rows
-# and/or columns by its diagonal elements and then undo the scaling on
-# the result. rcond() returns the reciprocal condition number net of
-# the above scaling. snearPD() wraps nearPD() to scale the diagonal
-# as well.
-#
-# This is useful when dealing with covariance matrices of variables
-# with very different orders of magnitude. Such matrices have very
-# large ratios between their greatest and their least eigenvalues,
-# causing them to appear to their algorithms to be near-singular when
-# they are actually very much SPD.
-#
-# snnd mode assumes that the matrix is symmetric non-negative definite
-# (SNND). If it's "obvious" that it's not (e.g., negative diagonal
-# elements), an error is raised.
-#
-# NB: In R, vector * matrix and matrix * vector always scales
-# corresponding rows.
-ssolve <- function(a, b, ..., snnd = TRUE){
-  if(missing(b)){
-    b <- diag(1, nrow(a))
-    colnames(b) <- rownames(a)
-  }
-
-  d <- diag(as.matrix(a))
-  d <- ifelse(d==0, 1, 1/d)
-
-  if(snnd){
-    d <- sqrt(d)
-    if(anyNA(d)) stop("Matrix a has negative elements on the diagonal, and snnd=TRUE.")
-    a <- a * d * rep(d, each = length(d))
-    solve(a, b*d, ...) * d
-  }else{
-    solve(a*d, b*d, ...)
-  }
-}
-
-
-#' @importFrom MASS ginv
-sginv <- function(X, ..., snnd = TRUE){
-  d <- diag(as.matrix(X))
-  d <- ifelse(d==0, 1, 1/d)
-
-  if(snnd){
-    d <- sqrt(d)
-    if(anyNA(d)) stop("Matrix a has negative elements on the diagonal, and snnd=TRUE.")
-    dd <- rep(d, each = length(d)) * d
-    X <- X * dd
-    ginv(X, ...) * dd
-  }else{
-    dd <- rep(d, each = length(d))
-    ginv(X*d, ...) * dd
-  }
-}
-
-srcond <- function(x, ..., snnd = TRUE){
-  d <- diag(as.matrix(x))
-  d <- ifelse(d==0, 1, 1/d)
-
-  if(snnd){
-    d <- sqrt(d)
-    if(anyNA(d)) stop("Matrix a has negative elements on the diagonal, and snnd=TRUE.")
-    dd <- rep(d, each = length(d)) * d
-    rcond(x*dd)
-  }else{
-    rcond(x*d, ...)
-  }
-}
-
-#' @importFrom Matrix nearPD
-snearPD <- function(x, ...){
-  d <- abs(diag(as.matrix(x)))
-  d[d==0] <- 1
-  d <- sqrt(d)
-  if(anyNA(d)) stop("Matrix x has negative elements on the diagonal.")
-  dd <- rep(d, each = length(d)) * d
-  x <- nearPD(x / dd, ...)
-  x$mat <- x$mat * dd
-  x
-}
-
-# These are somewhat inspired by emulator::quad.form.inv() and others.
-
-# x^T A x
-xTAx <- function(x, A){
-  drop(crossprod(crossprod(A, x), x))
-}
-# x A x^T
-xAxT <- function(x, A){
-  drop(x %*% tcrossprod(A, x))
-}
-
-# xT A^-1 x
-xTAx_ssolve <- function(x, A, ...){
-  drop(crossprod(x, ssolve(A, x, ...)))
-}
-
-# xT A^-1 x, but using QR decomposition and confirming that x is in
-# the span of A if A is singular; returns rank and nullity as
-# attributes just in case subsequent calculations (e.g., hypothesis
-# test degrees of freedom) are affected
-xTAx_qrsolve <- function(x, A, tol = 1e-07, ...){
-  Aqr <- qr(A, tol=tol, ...)
-  nullity <- NCOL(A) - Aqr$rank
-  if(nullity && !all(abs(crossprod(qr.Q(Aqr)[,-seq_len(Aqr$rank), drop=FALSE], x))<tol))
-    stop("x is not in the span of A")
-  structure(sum(x*qr.coef(Aqr, x), na.rm=TRUE), rank=Aqr$rank, nullity=nullity)
-}
-
-# Evaluate A^-1 B (A^T)^-1, minimising matrix inversion.
-sandwich_ssolve <- function(A, B, ...){
-  ssolve(A, t(ssolve(A, B, ...)), ...)
-}
-
-
-### Test if tergm has been updated (or hasn't been installed). This is needed to avoid breaking EpiModel's tests.
-has_new_tergm <- function() ERRVL(try(packageVersion("tergm") > "4.1.1", silent=TRUE), TRUE)
